@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2004-2010 Bastian Kleineidam
+# Copyright (C) 2004-2011 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -69,6 +69,10 @@ class TestFile (LinkCheckTest):
         # Opera bookmark file parsing
         self.file_test("opera6.adr")
 
+    def test_chromium_bookmarks (self):
+        # Google Chrome bookmark file parsing
+        self.file_test("Bookmarks")
+
     def test_directory_listing (self):
         # unpack non-unicode filename which cannot be stored
         # in the SF subversion repository
